/****************************************************************************
** $Id: qwindow.cpp,v 2.1 1997/08/06 15:05:48 hanord Exp $
**
** Implementation of QWindow class
**
** Created : 931211
**
** Copyright (C) 1992-1997 Troll Tech AS.  All rights reserved.
**
** This file is part of the free edition of Qt 1.31.
**
** See the file LICENSE included in the distribution for the usage
** and distribution terms, or http://www.troll.no/qt/license.html.
**
** IMPORTANT NOTE: You may NOT copy this file or any part of it into
** your own programs or libraries.
**
** (This file differs from the one in the commercial edition of Qt
** only by this comment.)
**
*****************************************************************************/

#include "qwindow.h"
#include "qpixmap.h"

RCSTAG("$Id: qwindow.cpp,v 2.1 1997/08/06 15:05:48 hanord Exp $");


/*!
  \class QWindow qwindow.h
  \brief The QWindow class is reserved for future extensions.

  This class is not yet finished.  It will contain intelligent handling of
  menus etc. in a future Qt release.
*/


/*!
  Constructs a window named \e name, which will be a child widget of
  \e parent.

  The widget flags \e f should normally be set to zero unless you know what you
  are doing.

  These arguments are sent to the QWidget constructor.
*/

QWindow::QWindow( QWidget *parent, const char *name, WFlags f )
    : QWidget( parent, name, f )
{
    initMetaObject();
}

/*!
  Destroys the window.
*/

QWindow::~QWindow()
{
}
